// set the dimensions and margins of the graph
const margin = {
    top: 100,
    right: 100,
    bottom: 100,
    left: 100,
  },
  // Calculate width and height based on window dimensions and margins
  width = window.innerWidth - margin.left - margin.right,
  height = window.innerHeight - margin.top - margin.bottom;

// append the svg object to the body of the page
const svg = d3
  .select('#my_dataviz') // Select the element with id 'my_dataviz'
  .append('svg') // Append an SVG element
  .attr('width', width + margin.left + margin.right - 50) // Set width of SVG
  .attr('height', height + margin.top + margin.bottom - 50) // Set height of SVG
  .append('g') // Append a group element
  .attr(
    'transform',
    `translate(${margin.left},${margin.top})`, // Apply translation to group element to accommodate margins
  );

// Append title to the graph
svg
  .append('text') // Append a text element
  .attr('x', width / 2) // Set x position for text
  .attr('y', -margin.top / 2) // Set y position for text
  .attr('text-anchor', 'middle') // Set text-anchor attribute to middle for center alignment
  .style('font-size', '20px') // Set font size
  .text(
    'Cotton AND CALORIES', // Set text content
  );

// Parse the Data from CSV file
d3.csv(
  'https://gist.githubusercontent.com/MounishKamineni/7bcc30b01386bc9e94d0082ddb12e017/raw/da04a877cacd719d822dffd2b80d213c36784bac/COTTONSALES', // URL of the CSV file
).then((data) => {
  // X axis setup
  const x = d3
    .scaleBand() // Create a band scale for x-axis
    .range([0, width]) // Set the range of x-axis
    .domain(data.map((d) => d.Cotton)) // Set the domain of x-axis based on data
    .padding(0.5); // Set padding between bars
  svg
    .append('g') // Append a group element for x-axis
    .attr('transform', `translate(0,${height})`) // Translate x-axis to bottom of SVG
    .call(d3.axisBottom(x)) // Call the axis function for x-axis
    .selectAll('text') // Select all text elements
    .style('text-anchor', 'middle'); // Set text-anchor attribute to middle for center alignment

  // x label
  svg
    .append('text') // Append a text element
    .attr(
      'transform',
      `translate(${width / 4},${height + 50})`, // Set position for text
    )
    .style('text-anchor', 'middle') // Set text-anchor attribute to middle for center alignment
    .text('Year'); // Set text content

  // Y axis setup
  const y = d3
    .scaleLinear() // Create a linear scale for y-axis
    .domain([1000, 5000]) // Set the domain of y-axis
    .range([height, 0]); // Set the range of y-axis

  svg.append('g').call(d3.axisLeft(y)); // Append a group element for y-axis and call the axis function for y-axis

  // y label
  svg
    .append('text') // Append a text element
    .attr('transform', 'rotate(-90)') // Rotate text by -90 degrees
    .attr('y', -100) // Set y position for text
    .attr('x', -height / 8) // Set x position for text
    .style('text-anchor', 'middle') // Set text-anchor attribute to middle for center alignment
    .text('Profit in Million'); // Set text content

  // Add points for total reviews
  svg
    .selectAll('.pointstotal') // Select all elements with class 'pointstotal'
    .data(data) // Bind data to selection
    .join('circle') // Join data with circle elements
    .attr('class', 'pointstotal') // Set class attribute
    .attr(
      'cx',
      (d) => x(d.Cotton) + x.bandwidth() / 2, // Set x position
    )
    .attr('cy', (d) => y(+d.Calories) / 100) // Set y position
    .attr('r', 4) // Set radius of circles
    .append('title') // Append a title element for tooltip
    .text(
      (d) =>
        'Profit of ' +
        d.Calories +
        ' million in the year ' +
        d.Cotton, // Set text content for tooltip
    );

  // Define line function for total sales
  const totalsalesline = d3
    .line()
    .x((d) => x(d.Cotton) + x.bandwidth() / 2) // Set x coordinate for line
    .y((d) => y(+d.Calories)); // Set y coordinate for line

  // Append path for total sales line
  svg
    .append('path') // Append a path element
    .datum(data) // Bind data to path
    .attr('class', 'line') // Set class attribute
    .attr('d', totalsalesline) // Set path data
    .attr('fill', 'none') // Set fill color to none
    .attr('stroke', 'green'); // Set stroke color to green
});
